@@ -108,6 +108,11 @@ EOF
             tls-cert-file $ROOT/assets/tls-certificate.crt
             tls-key-file $ROOT/assets/tls-certificate.key
             tls-ca-cert-file $ROOT/assets/tls-ca-certificate.crt
+EOF
+        fi
+        if [ "$VERSION" -ge '7000000' ]; then
+            cat >> "$TMP/redis-master$MASTER_INDEX.conf" <<EOF
+            enable-debug-command local
 EOF
         fi
         redis-server "$TMP/redis-master$MASTER_INDEX.conf"
@@ -203,6 +208,8 @@ elif [[ ${@: -1} =~ ^.*clustered(\.[0-9]{7,})?\.[^\.]*\.vtc(\.disabled)?$ ]]; th
         unixsocket $TMP/redis-server$INDEX.sock
         pidfile $TMP/redis-server$INDEX.pid
         cluster-enabled yes
+        cluster-announce-ip $IP
+        cluster-announce-port $PORT
         cluster-config-file $TMP/redis-server$INDEX-nodes.conf
         cluster-node-timeout 5000
         cluster-slave-validity-factor 0
@@ -234,15 +241,19 @@ EOF
         yes yes | redis-trib.rb create --replicas $REDIS_CLUSTER_REPLICAS $SERVERS > /dev/null
     fi
 
-    # Wait for all nodes to get the new configuration.
-    sleep 5
+    # Wait for cluster formation in a rudementary way.
+    [[ $IPV6 = 1 ]] && HOST=::1 || HOST=127.0.0.1
+    [[ $IPV6 = 1 ]] && PATTERN=::1 || PATTERN=127[.]0[.]0[.]
+    while [ $(redis-cli -h $HOST -p $((REDIS_CLUSTER_START_PORT+1)) CLUSTER SLOTS | grep "$PATTERN" | wc -l) -lt $REDIS_CLUSTER_SERVERS ]; do
+        sleep 1
+    done
+    sleep 1
 
     # Add to context:
     #   - All master nodes' addresses ordered by the slots they handle
     #     (redis_master1, redis_master2, ...).
     #   - An example key for each of those master nodes (redis_key_in_master1,
     #   redis_key_in_master2, ...).
-    [[ $IPV6 = 1 ]] && HOST=::1 || HOST=127.0.1
     INDEX=1
     while read LINE; do
         CONTEXT="\
